@@ -35,46 +35,23 @@ add.text <- function(x, column, ...) {
 }
 
 
-add.xlab <- function(x, column,
-                     xlab, xpos, fs.xlab, ff.xlab,
-                     overall, ymin.line, addrow,
-                     print.label, bottom.lr,
-                     newline.label.right, newline.label.left) {
+add.xlab <- function(x, column, xlab, xlab.add, newline.xlab,
+                     xpos, ypos, fs.xlab, ff.xlab) {
   ##
   pushViewport(viewport(layout.pos.col = column, xscale = x$range))
   ##
-  ## Check for "\n" in argument xlab
-  ##
-  clines <- twolines(xlab, arg = TRUE)
-  ##
-  if (clines$newline) {
-    newline.xlab <- TRUE
-    xlab <- clines$top
-    add.xlab <- clines$bottom
-  }
-  else
-    newline.xlab <- FALSE
-  ##
   ## Label on x-axis:
   ##
   grid.text(xlab,
             x = unit(xpos, "native"),
-            y = unit(ymin.line - 2.5 - (!addrow & !overall) -
-                     1 * (print.label & bottom.lr) -
-                     1 * (print.label & bottom.lr &
-                          (newline.label.right | newline.label.left)),
-                     "lines"),
+            y = unit(ypos, "lines"),
             just = "center",
             gp = gpar(fontsize = fs.xlab, fontface = ff.xlab))
   ##
   if (newline.xlab)
-    grid.text(add.xlab,
+    grid.text(xlab.add,
               x = unit(xpos, "native"),
-              y = unit(ymin.line - 2.5 - 1 -
-                       1 * (print.label & bottom.lr) -
-                       1 * (print.label & bottom.lr &
-                            (newline.label.right | newline.label.left)),
-                       "lines"),
+              y = unit(ypos - 1, "lines"),
               just = "center",
               gp = gpar(fontsize = fs.xlab, fontface = ff.xlab))
   ##
@@ -144,11 +121,10 @@ draw.axis <- function(x, column, yS, log.xaxis, at, label,
           label <- c(label, exp(max(xlim)))
       }
       at <- log(label)
-      label <- round(label, 2)
     }
     else {
       if (length(label) == 1 && is.logical(label) && label)
-        label <- round(at, 2)
+        label <- at
       at <- log(at)
     }
     grid.xaxis(at = at, label = label,
@@ -177,6 +153,12 @@ draw.ci.diamond <- function(TE, lower, upper,
                             size, min, max,
                             col.diamond, col.diamond.lines) {
   ##
+  if (min > max) {
+    tmp <- min
+    min <- max
+    max <- tmp
+  }
+  ##
   if (!is.na(TE) &&
       ((min <= TE & TE <= max) |
        (min <= lower & lower <= max) |
@@ -194,6 +176,12 @@ draw.ci.predict <- function(lower.predict, upper.predict,
                             size, min, max,
                             col.predict, col.predict.lines) {
   ##
+  if (min > max) {
+    tmp <- min
+    min <- max
+    max <- tmp
+  }
+  ##
   if (!(is.na(lower.predict) | is.na(upper.predict))) {
     ## Plot prediction interval only within plotting range
     if ((min <= lower.predict & lower.predict <= max) |
@@ -214,6 +202,12 @@ draw.ci.square <- function(TE, lower, upper,
                            col, col.square,
                            col.square.lines, col.inside) {
   ##
+  if (min > max) {
+    tmp <- min
+    min <- max
+    max <- tmp
+  }
+  ##
   if (!is.na(TE)) {
     ##
     ## Draw lines in colour "col.inside" if totally inside rect
@@ -335,43 +329,44 @@ draw.forest <- function(x, column) {
 draw.lines <- function(x, column,
                        ref, TE.fixed, TE.random,
                        overall, comb.fixed, comb.random, prediction,
-                       lwd, lty.fixed, lty.random, col.fixed, col.random,
-                       ymin.line, ymax.line,
-                       addrow, print.label, bottom.lr,
-                       spacing) {
+                       ylim.fixed, ylim.random, ylim.ref,
+		       lwd, lty.fixed, lty.random, col.fixed, col.random,
+                       min, max) {
+  ##
+  if (min > max) {
+    min <- x$range[2]
+    max <- x$range[1]
+  }
+  else {
+    min <- x$range[1]
+    max <- x$range[2]
+  }
   ##
   pushViewport(viewport(layout.pos.col = column, xscale = x$range))
   ##
   ## Reference line:
   ##
-  if (!is.na(ref) && (x$range[1] <= ref & ref <= x$range[2]))
+  if (!is.na(ref) && (min <= ref & ref <= max))
     grid.lines(x = unit(ref, "native"),
-               y = unit(spacing * c(ymin.line - (!addrow & !overall),
-                                    ymax.line + (print.label & !bottom.lr)),
-                        "lines"),
+               y = unit(ylim.ref, "lines"),
                gp = gpar(lwd = lwd))
   ##
   ## Line for fixed effect estimate:
   ##
   if (comb.fixed & overall & !is.na(TE.fixed))
-    if (x$range[1] <= TE.fixed & TE.fixed <= x$range[2])
+    if (min <= TE.fixed & TE.fixed <= max)
       if (!is.null(lty.fixed))
         grid.lines(x = unit(TE.fixed, "native"),
-                   y = unit(spacing * c(ymin.line + prediction +
-                                        comb.random + 0.5,
-                                        ymax.line - 1 * addrow),
-                            "lines"),
+                   y = unit(ylim.fixed, "lines"),
                    gp = gpar(lty = lty.fixed, lwd = lwd, col = col.fixed))
   ##
   ## Line for random effects estimate:
   ##
   if (comb.random & overall & !is.na(TE.random))
-    if (x$range[1] <= TE.random & TE.random <= x$range[2])
+    if (min <= TE.random & TE.random <= max)
       if (!is.null(lty.random) & !is.na(TE.random))
         grid.lines(x = unit(TE.random, "native"),
-                   y = unit(spacing * c(ymin.line + prediction + 0.5,
-                                        ymax.line - 1 * addrow),
-                            "lines"),
+                   y = unit(ylim.random, "lines"),
                    gp = gpar(lty = lty.random, lwd = lwd, col = col.random))
   ##
   popViewport()
