@@ -145,7 +145,7 @@ metaprop <- function(event, n, studlab,
   ##
   byvar <- eval(mf[[match("byvar", names(mf))]],
                 data, enclos = sys.frame(sys.parent()))
-  missing.byvar <- is.null(byvar)
+  by <- !is.null(byvar)
   ##
   subset <- eval(mf[[match("subset", names(mf))]],
                  data, enclos = sys.frame(sys.parent()))
@@ -167,7 +167,7 @@ metaprop <- function(event, n, studlab,
   if (length(incr) > 1)
     chklength(incr, k.All, fun)
   ##
-  if (!missing.byvar)
+  if (by)
     chklength(byvar, k.All, fun)
   ##
   ## Additional checks
@@ -185,11 +185,11 @@ metaprop <- function(event, n, studlab,
       tau.preset <- NULL
     }
   }
-  if (missing.byvar & tau.common) {
+  if (!by & tau.common) {
     warning("Value for argument 'tau.common' set to FALSE as argument 'byvar' is missing.")
     tau.common <- FALSE
   }
-  if (!missing.byvar & !tau.common & !is.null(tau.preset)) {
+  if (by & !tau.common & !is.null(tau.preset)) {
     warning("Argument 'tau.common' set to TRUE as argument tau.preset is not NULL.")
     tau.common <- TRUE
   }
@@ -217,7 +217,7 @@ metaprop <- function(event, n, studlab,
   else
     exclude <- rep(FALSE, k.All)
   ##  
-  if (!missing.byvar) {
+  if (by) {
     chkmiss(byvar)
     byvar.name <- byvarname(mf[[match("byvar", names(mf))]])
     bylab <- if (!missing(bylab) && !is.null(bylab)) bylab else byvar.name
@@ -241,7 +241,7 @@ metaprop <- function(event, n, studlab,
     ##
     data$.incr <- incr
     ##
-    if (!missing.byvar)
+    if (by)
       data$.byvar <- byvar
     ##
     if (!missing.subset) {
@@ -273,7 +273,7 @@ metaprop <- function(event, n, studlab,
     if (length(incr) > 1)
       incr <- incr[subset]
     ##
-    if (!missing.byvar)
+    if (by)
       byvar <- byvar[subset]
   }
   ##
@@ -489,10 +489,10 @@ metaprop <- function(event, n, studlab,
                ##
                control = control)
   ##
-  if (method != "GLMM" & !missing.byvar & tau.common) {
+  if (method != "GLMM" & by & tau.common) {
     ## Estimate common tau-squared across subgroups
-    hcc <- hetcalc(TE, seTE, method.tau, TE.tau, byvar,
-                   control = control)
+    hcc <- hetcalc(TE, seTE, method.tau, TE.tau,
+                   level.comb, byvar, control)
   }
   
   
@@ -615,28 +615,61 @@ metaprop <- function(event, n, studlab,
   ##
   ## Add results from subgroup analysis
   ##
-  if (!missing.byvar) {
+  if (by) {
     res$byvar <- byvar
     res$bylab <- bylab
     res$print.byvar <- print.byvar
     res$byseparator <- byseparator
     res$tau.common <- tau.common
     ##
-    if (!tau.common)
+    if (!tau.common) {
       res <- c(res, subgroup(res))
-    else if (!is.null(tau.preset))
+      res$tau.resid <- NA
+    }
+    else if (!is.null(tau.preset)) {
       res <- c(res, subgroup(res, tau.preset))
+      res$tau.resid <- NA
+    }
     else {
-      if (is.glmm)
+      if (is.glmm) {
         res <- c(res, subgroup(res, NULL,
                                factor(res$byvar, bylevs(res$byvar)), ...))
+        res$tau.resid <- NA
+      }
       else {
         res <- c(res, subgroup(res, hcc$tau))
         res$Q.w.random <- hcc$Q
         res$df.Q.w.random <- hcc$df.Q
+        res$tau.resid <- hcc$tau
       }
     }
     ##
+    if (!tau.common || method.tau == "DL") {
+      ci.H.resid <- calcH(res$Q.w.fixed, res$df.Q.w, level.comb)
+      ##
+      res$H.resid <- ci.H.resid$TE
+      res$lower.H.resid <- ci.H.resid$lower
+      res$upper.H.resid <- ci.H.resid$upper
+    }
+    else {
+      res$H.resid <- hcc$H.resid
+      res$lower.H.resid <- hcc$lower.H.resid
+      res$upper.H.resid <- hcc$upper.H.resid
+    }
+    ##
+    if (!tau.common || method.tau == "DL") {
+      ci.I2.resid <- isquared(res$Q.w.fixed, res$df.Q.w, level.comb)
+      ##
+      res$I2.resid <- ci.I2.resid$TE
+      res$lower.I2.resid <- ci.I2.resid$lower
+      res$upper.I2.resid <- ci.I2.resid$upper
+    }
+    else {
+      res$I2.resid <- hcc$I2.resid
+      res$lower.I2.resid <- hcc$lower.I2.resid
+      res$upper.I2.resid <- hcc$upper.I2.resid
+    }
+    ##
     res$event.e.w <- NULL
     res$event.c.w <- NULL
     res$n.e.w <- NULL
